# CHAMP Dataset

For more information about this package, including demos and documentations, please consult the project website at [https://yujunmao1.github.io/CHAMP/](https://yujunmao1.github.io/CHAMP/).